/**
 * Escape fieldname following the spec requirements.
 *
 * See: https://html.spec.whatwg.org/multipage/form-control-infrastructure.html#multipart-form-data
 *
 * @param name A fieldname to escape
 *
 * @api private
 */
declare const escapeName: (name: unknown) => string;
export default escapeName;
