import { FormDataLike } from "../FormDataLike";
/**
 * Check if given object is FormData
 *
 * @param value an object to test
 */
export declare const isFormData: (value?: unknown) => value is FormDataLike;
/**
 * Check if given object is FormData
 *
 * @param value an object to test
 *
 * @deprecated use `isFormData` instead.
 */
export declare const isFormDataLike: (value?: unknown) => value is FormDataLike;
