/**
 * Generates a boundary string for FormData encoder.
 *
 * @api private
 *
 * ```js
 * import createBoundary from "./util/createBoundary"
 *
 * createBoundary() // -> n2vw38xdagaq6lrv
 * ```
 */
declare function createBoundary(): string;
export default createBoundary;
